{% extends 'base_metro.html' %}

{% block titulo %}{{ titulo|title }}{% endblock %}

{% block content %}
    {% load filtros_metro %}
    {% if aplicacion|add:'.add_'|add:modelo in permisos  %}
        <div style="display: flex;margin-bottom: 10px;">
            <a href="crear" class="btn btn-large btn-success" >Crear {{ nom_modelo }}</a>
        </div>
    {% endif %}
    {% if lista_buscar %}
    <div class="row-fluid sortable">
				<div class="box span12">
					<div class="box-header" data-original-title>
						<h2><i class="halflings-icon th-list"></i><span class="break"></span>{{ nombre_app }} - {{ nom_modelo }}</h2>
						<div class="box-icon">
							<a href="#" class="btn-setting"><i class="halflings-icon wrench"></i></a>
							<a href="#" class="btn-minimize"><i class="halflings-icon chevron-up"></i></a>
							<a href="#" class="btn-close"><i class="halflings-icon remove"></i></a>
						</div>
					</div>
					<div class="box-content">
						<table class="table table-striped table-bordered bootstrap-datatable datatable">
						  <thead>
							  <tr>
                                  {% for titulo_field in titulo_field %}
								  <th>{{ titulo_field|title }}</th>
								  {% endfor %}
                                  <th style="width: 18%">Acciones</th>
							  </tr>
						  </thead>
						  <tbody>

                            {% for lista_buscar in lista_buscar %}
                                <tr>
                                {% for lista_fields in lista_fields %}
                                    <td>{% valor_field lista_buscar.id lista_fields aplicacion modelo   %} </td>
                                {% endfor %}
                                    <td class="center" >
{#								{% if aplicacion|add:'.view_'|add:modelo in permisos  %}
    									<a class="btn btn-success" href="{{ lista_buscar.id }}">
    										<i class="halflings-icon white zoom-in"></i>
    									</a>
                  {% endif %}
                                    {% if aplicacion|add:'.change_'|add:modelo in permisos  %}
									<a class="btn btn-info" href="{{ lista_buscar.id }}">
										<i class="halflings-icon white edit"></i>
									</a>
                                    {% endif %}
                                    {% if aplicacion|add:'.delete_'|add:modelo in permisos  %}
									<a class="btn btn-danger btn-eliminar" id="{{ lista_buscar.id }}">
										<i class="halflings-icon white trash"></i>
									</a>
                                    {% endif %}
								</td>
                                </tr>
                            {% endfor %}



						  </tbody>
					  </table>
					</div>
				</div><!--/span-->

			</div><!--/row-->
            {% if aplicacion|add:'.delete_'|add:modelo in permisos  %}
            <div class="modal hide fade" id="ConfirmaEliminar">
                    <div class="modal-header">
                        <button type="button" class="close" data-dismiss="modal">×</button>
                        <h3>Elimiar {{ modelo }}</h3>
                    </div>
                    <div class="modal-body">
                        <p>Seguro desea elimiar esta(e) {{ modelo }}</p>
                    </div>
                    <div class="modal-footer">
                        <a class="btn btn-danger" data-dismiss="modal">No</a>
                        <a class="btn btn-primary eliminar">Si</a>
                    </div>
                </div>
            {% endif %}
    {% else %}
        <h2><span class="break"></span>No Existen registros</h2>
    {% endif %}


{% endblock %}

{% block js %}

    <script>
        var a =0;
        $('.btn-eliminar').click(function(f){
            f.preventDefault();
    		$('#ConfirmaEliminar').modal('show');
            a=f.currentTarget.id;
        });
        $('.eliminar').click(function(f){
            f.preventDefault();
    		$('#ConfirmaEliminar').modal('hide');
            Eliminar(a);
        });
        function Eliminar(id){
            var url      = window.location.pathname;
            $.get(url+id+'/eliminar', function(data, status){
                console.log(data);
                if(data=='Eliminado Correctamente'){
                    $('#ConfirmaEliminar').modal('hide');
                    retorno=window.location.pathname;
                    $(location).attr('href',  retorno+'#eliminado');
                    window.location.reload();

                }
                if(data=='No Tienes Permiso'){
                    $('#ConfirmaEliminar').modal('hide');
                    retorno=window.location.pathname;
                    $(location).attr('href',  retorno+'#sinpermiso');
                    window.location.reload();

                }
            });
        }
        $( document ).ready(function() {
            var url= window.location.href;
            if(url.indexOf("#eliminado") != -1){
                $.gritter.add({
                    // (string | mandatory) the heading of the notification
                    title: 'Felicitaciones',
                    // (string | mandatory) the text inside the notification
                    text: 'Eliminaste Correctamente a esta(e) {{ modelo }}'
                });
            }
            if(url.indexOf("#sinpermiso") != -1){
                $.gritter.add({
                    // (string | mandatory) the heading of the notification
                    title: 'Lo Sentimos',
                    // (string | mandatory) the text inside the notification
                    text: 'No tienes permiso para eliminar esta(e) {{ modelo }}'
                });
            }
        });
    </script>

{% endblock %}
