{% extends 'base_metro.html' %}

{% block titulo %}{{ titulo|title }}{% endblock %}

{% block content %}
    <div class="row-fluid">
            <style>
                .quick-button {
                    margin-bottom: 18px;
                }
            </style>
                {% for apps in lista_apps_botones %}
                    {% if titulo|add:'.view_'|add:apps.nombre in permisos  %}
                    <a href="/{{ titulo|lower }}/{{ apps.nombre }}" style="margin-left: 0;margin-right: 10px;border-radius: 10px" class="quick-button metro {% cycle 'yellow' 'green' 'red' 'pink' 'orange' 'black' %} span6">
                    {% if icono %}
                    <i class="{{ icono }}"></i>
                    {% else %}
                    <i class="icon-chevron-right"></i>
                    {% endif %}
                    <p>{{ apps.nombre_modelo|title }}</p>
{#					<span class="badge">237</span>#}
                    {% endif %}
				</a>
                {% endfor %}
        <div class="clearfix"></div>
    </div><!--/row-->


{% endblock %}
