.dark {
	right: -25px;	
}

.btn-overlay {
	filter: none !important;	
}

hr,
.sliderOverlay,
.progressBarOverlay,
.slider,
.progress,
.progressSlim,
.ui-progressbar-value,
.ui-slider-range,
.sliderVertical {
	filter: none !important;
}

.verticalChart .singleBar .bar .value span{
	color: #3b3b41;
}