{% extends 'base_metro.html' %}

{% block titulo %}{{ titulo }}{% endblock %}

{% block content %}
    <div class="row-fluid">
            <style>
                .quick-button {
                    margin-bottom: 18px;
                }
            </style>
                {% for apps in apps %}
				<a href="/{{ apps.app }}" style="margin-left: 0;margin-right: 10px;border-radius: 10px;" class="quick-button metro {% cycle 'yellow' 'green' 'red' 'pink' 'orange' 'black' %} span6">
					<i class="{{ apps.icon }}"></i>
					<p>{{ apps.label|title }}</p>
{#					<span class="badge">237</span>#}
				</a>
                {% endfor %}
        <div class="clearfix"></div>
    </div><!--/row-->


{% endblock %}
